## Data From Auditing Job Ads on Facebook and LinkedIn for Discrimination

This webpage documents a dataset related to our study of discrimination in job ad delivery on Facebook and LinkedIn.

### Paper

Our methodology is described in the following paper:

> Title: Discrimination in Algorithms Delivering Job Ads
> Authors: [Basileal Imana](https://ant.isi.edu/~imana/), [Aleksandra Korolova](https://www.korolova.com/), and [John Heidemann](https://www.isi.edu/~johnh/)
> Venue: In Proceedings of the Web Conference 2021 (WWW '21), April 19–23, 2021, Ljubljana, Slovenia.
> Links: [https://doi.org/10.1145/3442381.3450077](https://doi.org/10.1145/3442381.3450077), [bibtex](https://ant.isi.edu/datasets/addelivery/Imana21a.bib).

The data from this paper is below.

### Dataset Content:
There is one .csv file for each of the two platforms that contain the details for each ad ran.
* `README.md`: A copy of this README
* `all_fb_ads.csv`: A csv file with all Facebook ad parameters and results
* `all_li_ads.csv`: A csv file with all LinkedIn ad parameters and results
* `facebook_ad_screenshots/*.jpg`:  Screenshots of ads ran on Facebook
* `linkdein_ad_screenshots/*.jpg`: Screenshots of ads ran on LinkedIn
* `job_post_html/*.html`: HTML file scraped from job postings advertised
* `li_and_fb_objectives/*.html`:  HTML file of Facebook's or LinkedIn's documentation for campaign objectives

### Specific Experiments:
We list specific advertisements below, by figure in the paper. Each campaign ID is unique and can be used to identify the corresponding row in the files `all_fb_ads.csv` (for Facebook) and  `all_li_ads.csv` (for LinkedIn).

#### Figure 3: Measuring discrimination in delivery of real-world ads on LinkedIn and Facebook
* Figure3a: Delivery Driver at Domino's vs. Instacart (LinkedIn)
  * Camp ID: 160932216  (Instacart, audience#2f)
  * Camp ID: 160932206  (Dominos, audience#2f)
  * Camp ID: 160932316  (Instacart, audience#1f)
  * Camp ID: 160932296  (Dominos, audience#1f)
  * Camp ID: 160931946  (Instacart, audience#2)
  * Camp ID: 160931926  (Dominos, audience#2)

* Figure3a: Delivery Driver at Domino's vs. Instacart (Facebook)
  * Camp ID: 6215013647494  (Instacart, audience#0f)
  * Camp ID: 6215013646494  (Dominos, audience#0f)
  * Camp ID: 6215013646294  (Instacart, audience#1)
  * Camp ID: 6215013646094  (Dominos, audience#1)
  * Camp ID: 6215013647294  (Instacart, audience#0)
  * Camp ID: 6215013646694  (Dominos, audience#0)

* Figure3b: Software Engineer at Nvidia vs. Netflix (LinkedIn)
  * Camp ID: 160985336  (Nvidia, audience#2f)
  * Camp ID: 160985306  (Netflix, audience#2f)
  * Camp ID: 174320124  (Nvidia, audience#1f)
  * Camp ID: 174320104  (Netflix, audience#1f)
  * Camp ID: 160985266  (Nvidia, audience#2)
  * Camp ID: 160985256  (Netflix, audience#2)

* Figure3b: Software Engineer at Nvidia vs. Netflix (Facebook)
  * Camp ID: 6216261142094  (Nvidia, audience#2f)
  * Camp ID: 6216261141694  (Netflix, audience#2f)
  * Camp ID: 6216261141294  (Nvidia, audience#1f)
  * Camp ID: 6216261141894  (Netflix, audience#1f)
  * Camp ID: 6216251077094  (Nvidia, audience#2)
  * Camp ID: 6216251076894  (Netflix, audience#2)

* Figure3c: Sales Associate at Leith vs. Reeds (LinkedIn)
  * Camp ID: 174427024  (Reeds, audience#2f)
  * Camp ID: 174427074  (Leith, audience#2f)
  * Camp ID: 174427824  (Reeds, audience#1f)
  * Camp ID: 174427844  (Leith, audience#1f)
  * Camp ID: 174426704  (Reeds, audience#2)
  * Camp ID: 174426764  (Leith, audience#2)

* Figure3c: Sales Associate at Leith vs. Reeds (Facebook)
  * Camp ID: 6215015439894  (Reeds, audience#0f)
  * Camp ID: 6215015441294  (Leith, audience#0f)
  * Camp ID: 6215015440094  (Reeds, audience#1)
  * Camp ID: 6215015440494  (Leith, audience#1)
  * Camp ID: 6215015440294  (Reeds, audience#0)
  * Camp ID: 6215015441894  (Leith, audience#0)

#### Figure 4: Comparision of ad delivery using "Reach" and "Conversion" objectives on Facebook

* Figure4a: Delivery Driver at Domino's vs. Instacart (Conversion)
  * Camp ID: 6215013647494  (Instacart, audience#0f)
  * Camp ID: 6215013646494  (Dominos, audience#0f)
  * Camp ID: 6215013646294  (Instacart, audience#1)
  * Camp ID: 6215013646094  (Dominos, audience#1)
  * Camp ID: 6215013647294  (Instacart, audience#0)
  * Camp ID: 6215013646694  (Dominos, audience#0)

* Figure4a: Delivery Driver at Domino's vs. Instacart (Reach)
  * Camp ID: 6214734608694  (Instacart, audience#0f)
  * Camp ID: 6214734607894  (Dominos, audience#0f)
  * Camp ID: 6214733652094  (Instacart, audience#1)
  * Camp ID: 6214733652294  (Dominos, audience#1)
  * Camp ID: 6214659548294  (Instacart, audience#0)
  * Camp ID: 6214659547894  (Dominos, audience#0)

* Figure4b: Software Engineer at Nvidia vs. Netflix (Conversion)
  * Camp ID: 6216261142094  (Nvidia, audience#2f)
  * Camp ID: 6216261141694  (Netflix, audience#2f)
  * Camp ID: 6216261141294  (Nvidia, audience#1f)
  * Camp ID: 6216261141894  (Netflix, audience#1f)
  * Camp ID: 6216251077094  (Nvidia, audience#2)
  * Camp ID: 6216251076894  (Netflix, audience#2)

* Figure4b: Software Engineer at Nvidia vs. Netflix (Reach)
  * Camp ID: 6216490558894  (Nvidia, audience#2f)
  * Camp ID: 6216490558694  (Netflix, audience#2f)
  * Camp ID: 6216490561694  (Nvidia, audience#1f)
  * Camp ID: 6216490558494  (Netflix, audience#1f)
  * Camp ID: 6216490559694  (Nvidia, audience#2)
  * Camp ID: 6216490559094  (Netflix, audience#2)

* Figure4c: Sales Associate at Leith vs. Reeds (Conversion)
  * Camp ID: 6215015439894  (Reeds, audience#0f)
  * Camp ID: 6215015441294  (Leith, audience#0f)
  * Camp ID: 6215015440094  (Reeds, audience#1)
  * Camp ID: 6215015440494  (Leith, audience#1)
  * Camp ID: 6215015440294  (Reeds, audience#0)
  * Camp ID: 6215015441894  (Leith, audience#0)

* Figure4c: Sales Associate at Leith vs. Reeds (Reach)
  * Camp ID: 6214681030694  (Reeds, audience#0f)
  * Camp ID: 6214681030294  (Leith, audience#0f)
  * Camp ID: 6214680936094  (Reeds, audience#1)
  * Camp ID: 6214680936894  (Leith, audience#1)
  * Camp ID: 6214665668294  (Reeds, audience#0)
  * Camp ID: 6214665667894  (Leith, audience#0)

### Experimental Data:
* [linkedin-and-facebook-job-ad-delivery-20210214.zip](https://ant.isi.edu/datasets/addelivery/linkedin-and-facebook-job-ad-delivery-20210214.zip)